package com.ruoyi.tuya.service;

import java.util.List;
import com.ruoyi.tuya.domain.BusSupplierReleaseDay;

/**
 * 平台报价单明细Service接口
 * 
 * @author zf
 * @date 2022-07-22
 */
public interface IBusSupplierReleaseDayService 
{
    /**
     * 查询平台报价单明细
     * 
     * @param id 平台报价单明细主键
     * @return 平台报价单明细
     */
    public BusSupplierReleaseDay selectBusSupplierReleaseDayById(Long id);

    /**
     * 查询平台报价单明细列表
     * 
     * @param busSupplierReleaseDay 平台报价单明细
     * @return 平台报价单明细集合
     */
    public List<BusSupplierReleaseDay> selectBusSupplierReleaseDayList(BusSupplierReleaseDay busSupplierReleaseDay);

    /**
     * 新增平台报价单明细
     * 
     * @param busSupplierReleaseDay 平台报价单明细
     * @return 结果
     */
    public int insertBusSupplierReleaseDay(BusSupplierReleaseDay busSupplierReleaseDay);

    /**
     * 修改平台报价单明细
     * 
     * @param busSupplierReleaseDay 平台报价单明细
     * @return 结果
     */
    public int updateBusSupplierReleaseDay(BusSupplierReleaseDay busSupplierReleaseDay);

    /**
     * 批量删除平台报价单明细
     * 
     * @param ids 需要删除的平台报价单明细主键集合
     * @return 结果
     */
    public int deleteBusSupplierReleaseDayByIds(Long[] ids);

    /**
     * 删除平台报价单明细信息
     * 
     * @param id 平台报价单明细主键
     * @return 结果
     */
    public int deleteBusSupplierReleaseDayById(Long id);
}
